==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/TimeAxisLabelFormatDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisLabelFormatDescription } from "./TimeAxisLabelFormatDescription";
/**
 * @hidden
 */
var TimeAxisLabelFormatDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TimeAxisLabelFormatDescriptionMetadata, _super);
    function TimeAxisLabelFormatDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TimeAxisLabelFormatDescriptionMetadata.b = function (a) {
        if (TimeAxisLabelFormatDescriptionMetadata.a == null) {
            TimeAxisLabelFormatDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TimeAxisLabelFormatDescriptionMetadata.c(TimeAxisLabelFormatDescriptionMetadata.a);
        }
        if (a.k(TimeAxisLabelFormatDescriptionMetadata.a)) {
            return;
        }
        a.ab(TimeAxisLabelFormatDescriptionMetadata.a);
    };
    TimeAxisLabelFormatDescriptionMetadata.c = function (a) {
        a.item("Range", "TimeSpan");
        a.item("Format", "String");
        a.item("RepeatedYearFormat", "String");
        a.item("RepeatedMonthFormat", "String");
        a.item("RepeatedDayFormat", "String");
    };
    TimeAxisLabelFormatDescriptionMetadata.d = function (a) {
        TimeAxisLabelFormatDescriptionMetadata.b(a);
        a.ad("TimeAxisLabelFormat", function () { return new TimeAxisLabelFormatDescription(); });
        a.ac("TimeAxisLabelFormat", TimeAxisLabelFormatDescriptionMetadata.a);
    };
    TimeAxisLabelFormatDescriptionMetadata.$t = markType(TimeAxisLabelFormatDescriptionMetadata, 'TimeAxisLabelFormatDescriptionMetadata');
    TimeAxisLabelFormatDescriptionMetadata.a = null;
    return TimeAxisLabelFormatDescriptionMetadata;
}(Base));
export { TimeAxisLabelFormatDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/TimeAxisLabelFormatDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisLabelFormatDescription } from "./TimeAxisLabelFormatDescription";
/**
 * @hidden
 */
var TimeAxisLabelFormatDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TimeAxisLabelFormatDescriptionMetadata, _super);
    function TimeAxisLabelFormatDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TimeAxisLabelFormatDescriptionMetadata.b = function (a) {
        if (TimeAxisLabelFormatDescriptionMetadata.a == null) {
            TimeAxisLabelFormatDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TimeAxisLabelFormatDescriptionMetadata.c(TimeAxisLabelFormatDescriptionMetadata.a);
        }
        if (a.k(TimeAxisLabelFormatDescriptionMetadata.a)) {
            return;
        }
        a.ac(TimeAxisLabelFormatDescriptionMetadata.a);
    };
    TimeAxisLabelFormatDescriptionMetadata.c = function (a) {
        a.item("Range", "TimeSpan");
        a.item("Format", "String");
        a.item("RepeatedYearFormat", "String");
        a.item("RepeatedMonthFormat", "String");
        a.item("RepeatedDayFormat", "String");
    };
    TimeAxisLabelFormatDescriptionMetadata.d = function (a) {
        TimeAxisLabelFormatDescriptionMetadata.b(a);
        a.ae("TimeAxisLabelFormat", function () { return new TimeAxisLabelFormatDescription(); });
        a.ad("TimeAxisLabelFormat", TimeAxisLabelFormatDescriptionMetadata.a);
    };
    TimeAxisLabelFormatDescriptionMetadata.$t = markType(TimeAxisLabelFormatDescriptionMetadata, 'TimeAxisLabelFormatDescriptionMetadata');
    TimeAxisLabelFormatDescriptionMetadata.a = null;
    return TimeAxisLabelFormatDescriptionMetadata;
}(Base));
export { TimeAxisLabelFormatDescriptionMetadata };
